
    #   Find barycentre extrema in output from bary_minmax_csv.pl
    
    #	Input:	bary_minmax.csv     (Output from bary_minmax_csv.pl)
    #	Output: bary_extrema.csv    (CSV database sorted by barycentre distance from centre of Sun)
    
    #	by John Walker
    #	http://www.fourmilab.ch/
    
    #	For details, please see: http://www.fourmilab.ch/documents/canon_transits/

    use strict;
    use warnings;
    
    my $l;
    my @extrema;

    open(FI, "<bary_minmax.csv") || die("Cannot open bary_minmax.csv");
    open(FO, ">bary_extrema.csv") || die("Cannot write bary_extrema.csv");
    while ($l = <FI>) {
	$l =~ s/\s+$//;
   	$l =~ m/^(\w+),([^,]+),([^,]+),(.*)$/ || die("Parse error on $l");
	my ($event, $G, $jd, $caldate) = ($1, $2, $3, $4);
    	if ($event =~ m/^(min|max)G/) {
	    my $ejd = sprintf("%.2f", $jd);
	    push(@extrema, "$G,$ejd,$caldate");
	}
    }
    @extrema = sort(by_displacement  @extrema);
    close(FI);
    
    for (my $i = 0; $i <= $#extrema; $i++) {
    	print(FO "$extrema[$i]\n");
    }
    close(FO);
    
    sub by_displacement {
    	$a =~ m/^([^\,]+),/ || die("by_displacement match failed ($a)");
	my $Ga = $1;
    	$b =~ m/^([^\,]+),/ || die("by_displacement match failed ($b)");
	my $Gb = $1;
	return $Ga <=> $Gb;
    }
